@@ -257,7 +257,7 @@ class WebIDUser(User):
     @staticmethod
     def get_for_uri(uri):
         try:
-            return WebIDUser.objects.get(stored_webiduris__uri=None)
+            return WebIDUser.objects.get(stored_webiduris__uri=uri)
         except WebIDUser.DoesNotExist:
             return None
 
